@@ -10,27 +10,33 @@ readWav = function(filename, start = 1, end = 100, units = "minutes") {
   # extract info from header: fileEncoding does not seem to be consistent, so try variants
   header = header_rownames = c()
   Nlines = 18
-  while (length(header) == 0 | 
-         length(grep("Scale-3",header)) == 0 |
-         length(grep("Scale-2",header)) == 0 |
-         length(grep("Scale-1",header)) == 0) { # as we do not know what header size is, search for it (needed in R version =< 3.1)
-    
+  options(warn = -1) # ignore warnings with unknown character is fields
+  skiprow = 0
+  while (length(header) == 0 |
+         length(grep("Scale-3", header)) == 0 |
+         length(grep("Scale-2", header)) == 0 |
+         length(grep("Scale-1", header)) == 0) {
+
     try(expr = {header = suppressWarnings(read.csv(filename,
-                                                   nrow = Nlines, header = TRUE))}, silent = TRUE)
+                                                   nrow = Nlines, skip = skiprow,
+                                                   header = TRUE))}, silent = TRUE)
     if (length(header) == 0) {
-      header = suppressWarnings(read.csv(filename, skipNul = TRUE,
-                                         nrow = Nlines, header = TRUE,
-                                         fileEncoding = "WINDOWS-1252"))
+      try(expr = {header = suppressWarnings(read.csv(filename, skipNul = TRUE,
+                                         nrow = Nlines, skip = skiprow,
+                                         header = TRUE,
+                                         fileEncoding = "WINDOWS-1252"))}, silent = TRUE)
     }
     if (length(header) == 0) {
-      header = suppressWarnings(read.csv(filename, skipNul = TRUE,
-                                         nrow = Nlines, header = TRUE,
-                                         fileEncoding = "UTF-8"))
+      try(expr = {header = suppressWarnings(read.csv(filename, skipNul = TRUE,
+                                         nrow = Nlines, skip = skiprow,
+                                         header = TRUE,
+                                         fileEncoding = "UTF-8"))}, silent = TRUE)
     }
     if (length(header) == 0) {
-      header = suppressWarnings(read.csv(filename, skipNul = TRUE,
-                                         nrow = Nlines, header = TRUE,
-                                         fileEncoding = "latin1"))
+      try(expr = {header = suppressWarnings(read.csv(filename, skipNul = TRUE,
+                                         nrow = Nlines, skip = skiprow,
+                                         header = TRUE,
+                                         fileEncoding = "latin1"))}, silent = TRUE)
     }
     if (length(header) > 0) {
       header_rownames = rownames(header)
@@ -40,10 +46,19 @@ readWav = function(filename, start = 1, end = 100, units = "minutes") {
         header = header_rownames
       }
     }
+    
+    if (Nlines == 10) {
+      if (skiprow == 0) {
+        skiprow = 1
+        Nlines = 18
+      } else {
+       stop("wav file header not recognized in function readWav from the GGIRread package")
+      }
+    }
     Nlines = Nlines - 1
-    if (Nlines == 10) print("Error: wav file header not recognized in function readWav from the GGIRread package")
   }
   scale3position = grep("Scale-3", header)
+  options(warn = 0)
   header = header[1:scale3position]
   P = sapply(as.character(header),function(x) {
     tmp = unlist(strsplit(x,": "))
@@ -53,14 +68,29 @@ readWav = function(filename, start = 1, end = 100, units = "minutes") {
       tmp = c(tmp[1],tmp[length(tmp)])
     }
   })
-  P = as.data.frame(t(P), stringsAsFactors = TRUE)
+ 
+  H = tuneR::readWave(filename, from = 1, to = 3600,units = c("seconds"), header = TRUE) #get wav file header
+  if ("sample.rate" %in% names(H)) {
+    P = cbind(P, c("sample.rate", as.character(H$sample.rate)))
+  }
+  if (is.list(P) == TRUE) {
+    conv = c()
+    for (jj in 1:length(P)) {
+      conv = rbind(conv, P[[jj]], stringsAsFactors = TRUE)
+    }
+    P = as.data.frame(conv, stringsAsFactors = TRUE)
+  } else {
+    P = as.data.frame(t(P), stringsAsFactors = TRUE)
+  }
   names(P) = c("hnames","hvalues")
   row.names(P) = 1:nrow(P)
-  H = tuneR::readWave(filename, from = 1, to = 3600,units = c("seconds"), header = TRUE) #get wav file header
+  
   #-----------------------------------------------
   # scale acceleration
   scale = as.numeric(as.character(P$hvalues[which(P$hnames == "Scale-1" | P$hnames == "Scale-2" | P$hnames == "Scale-3")]))
   
+  
+  
   if (length(scale) != 3) scale = rep(scale[1],3)
   range = 2^(H$bits - 1) # should be 32768 for 16 bit
   x = (B$C1/range) * scale[1]
@@ -71,10 +101,15 @@ readWav = function(filename, start = 1, end = 100, units = "minutes") {
   # get time (we only need first timestamp) --> from header
   A = suppressWarnings(scan(filename, what = "character", nlines = 12,
                             quiet = TRUE, skipNul = TRUE)) #skipNul avoids undesired warning
+  
+  options(warn = -1) # ignore warnings with unknown character is fields
   timestamp = paste0(A[grep("ICMTz", A) + 1:2], collapse = " ")
+  options(warn = 0)
+
   if (length(timestamp) == 0 | timestamp == "") { #if not possible use other time in fileheader
     timestamp = as.character(P$hvalues[which(P$hnames == "Start")])
   }
+
   # Note: temperature information is available in channel 4, but documentation is unclear on how to interpret this information
   # therefore I am not using it and rely on auto-calibration as performed before .wav file is generated
   # g = (B$C4/ range) # temperature, light and battery ?
